import type { Control, EachOptions } from '../../@types/each.js';
/**
 * Handle **global states** and **external** services before each `test` or `it`.
 *
 * ---
 *
 * ```ts
 * import { beforeEach } from 'poku';
 *
 * const before = beforeEach(() => {
 *   
 * };
 *
 * before.pause();
 * before.continue();
 * before.reset();
 * ```
 */
export declare const beforeEach: (callback: () => unknown, options?: EachOptions) => Control;
/**
 * Handle **global states** and **external** services after each `test` or `it`.
 *
 * ---
 *
 * ```ts
 * import { afterEach } from 'poku';
 *
 * const after = afterEach(() => {
 *   
 * };
 *
 * after.pause();
 * after.continue();
 * after.reset();
 * ```
 */
export declare const afterEach: (callback: () => unknown) => Control;
