"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
var _a;
Object.defineProperty(exports, "__esModule", { value: true });
exports.processAsyncAssert = exports.processAssert = void 0;
const node_assert_1 = require("assert");
const node_process_1 = __importDefault(require("process"));
const node_path_1 = __importDefault(require("path"));
const find_file_from_stack_js_1 = require("../parsers/find-file-from-stack.js");
const assert_js_1 = require("../parsers/assert.js");
const indentation_js_1 = require("../configs/indentation.js");
const format_js_1 = require("./format.js");
const write_js_1 = require("./write.js");
const cwd = node_process_1.default.cwd();
const regexFile = /file:(\/\/)?/;
const assertProcessor = () => {
    var _a, _b;
    const isPoku = typeof ((_a = node_process_1.default.env) === null || _a === void 0 ? void 0 : _a.FILE) === 'string' && ((_b = node_process_1.default.env) === null || _b === void 0 ? void 0 : _b.FILE.length) > 0;
    const FILE = node_process_1.default.env.FILE;
    let preIdentation = '';
    const handleSuccess = (options) => {
        if (typeof options.message === 'string') {
            if (indentation_js_1.indentation.hasDescribe) {
                preIdentation += '  ';
            }
            if (indentation_js_1.indentation.hasItOrTest) {
                preIdentation += '  ';
            }
            const message = isPoku && !indentation_js_1.indentation.hasDescribe && !indentation_js_1.indentation.hasItOrTest
                ? `${preIdentation}${(0, format_js_1.format)(`${(0, format_js_1.format)(`✔ ${options.message}`).bold()} ${(0, format_js_1.format)(`› ${FILE}`).success().dim()}`).success()}`
                : `${preIdentation}${(0, format_js_1.format)(`✔ ${options.message}`).success().bold()}`;
            write_js_1.Write.log(message);
        }
        preIdentation = '';
    };
    const handleError = (error, options) => {
        node_process_1.default.exitCode = 1;
        if (error instanceof node_assert_1.AssertionError) {
            const { code, actual, expected, operator } = error;
            const absolutePath = (0, find_file_from_stack_js_1.findFile)(error).replace(regexFile, '');
            const file = node_path_1.default.relative(node_path_1.default.resolve(cwd), absolutePath);
            if (indentation_js_1.indentation.hasDescribe) {
                preIdentation += '  ';
            }
            if (indentation_js_1.indentation.hasItOrTest) {
                preIdentation += '  ';
            }
            let message = '';
            if (typeof options.message === 'string') {
                message = options.message;
            }
            else if (options.message instanceof Error) {
                message = options.message.message;
            }
            else if (typeof options.defaultMessage === 'string') {
                message = options.defaultMessage;
            }
            const finalMessage = (message === null || message === void 0 ? void 0 : message.trim().length) > 0
                ? (0, format_js_1.format)(`✘ ${message}`).fail().bold()
                : (0, format_js_1.format)('✘ Assertion Error').fail().bold();
            write_js_1.Write.log(isPoku
                ? `${preIdentation}${finalMessage} ${(0, format_js_1.format)(`› ${FILE}`).fail().dim()}`
                : `${preIdentation}${finalMessage}`);
            file &&
                write_js_1.Write.log(`${(0, format_js_1.format)(`${preIdentation}      File`).dim()} ${file}`);
            write_js_1.Write.log(`${(0, format_js_1.format)(`${preIdentation}      Code`).dim()} ${code}`);
            write_js_1.Write.log(`${(0, format_js_1.format)(`${preIdentation}  Operator`).dim()} ${operator}\n`);
            if (!(options === null || options === void 0 ? void 0 : options.hideDiff)) {
                const splitActual = (0, assert_js_1.parseResultType)(actual).split('\n');
                const splitExpected = (0, assert_js_1.parseResultType)(expected).split('\n');
                write_js_1.Write.log((0, format_js_1.format)(`${preIdentation}  ${(options === null || options === void 0 ? void 0 : options.actual) || 'Actual'}:`).dim());
                for (const line of splitActual) {
                    write_js_1.Write.log(`${preIdentation}  ${(0, format_js_1.format)(line).fail().bold()}`);
                }
                write_js_1.Write.log(`\n${preIdentation}  ${(0, format_js_1.format)(`${(options === null || options === void 0 ? void 0 : options.expected) || 'Expected'}:`).dim()}`);
                for (const line of splitExpected) {
                    write_js_1.Write.log(`${preIdentation}  ${(0, format_js_1.format)(line).success().bold()}`);
                }
                preIdentation = '';
            }
            if (options.throw) {
                console.error(error);
                write_js_1.Write.hr();
            }
            if (isPoku) {
                throw error;
            }
        }
        
        throw error;
    };
    const processAssert = (cb, options) => {
        try {
            cb();
            handleSuccess(options);
        }
        catch (error) {
            handleError(error, options);
        }
    };
    const processAsyncAssert = async (cb, options) => {
        try {
            await cb();
            handleSuccess(options);
        }
        catch (error) {
            handleError(error, options);
        }
    };
    return { processAssert, processAsyncAssert };
};
_a = assertProcessor(), exports.processAssert = _a.processAssert, exports.processAsyncAssert = _a.processAsyncAssert;
